

topika
======

topika = *to*\rnado *pika*, a backport of `aio_pika <https://aio-pika.readthedocs.io/en/latest/>`_ for python 2.7+.

Where possible there API has been kept as close to aio_pika as possible, however due to the lack of native support for
coroutine async calls modifications had to be made.

Installation
------------

.. code-block:: shell

    pip install topika


